function [size] = sizeparam_normal_distn(prob, d)
%SIZEPARAM_NORMAL_DISTN Calculates the size paramater for a d-dimensional
%                 hyperellipsoid conforming to a normal (i.e., Gaussian)
%                 distribution.
%
% Syntax:      [size] = sizeparam_normal_distn(prob, d)
%
% Inputs:
%              prob - the target probability threshold
%              d - number of dimensions in the multivariate distribution
%
% Outputs:
%              size - the appropriate (scalar) size parameter
%
% Example: 
%              % Estimate the mean and covariance matrix from the data:
%              [mu, sig] = my_normdist_estimator(data);
%              % Get the number of dimensions:
%              d = length(data(1,:));
%              % Get the size parameter at a 95% threshold:
%              calpha = sizeparam_normal_distn(.95, d);
%              % Create a hyperellipsoid object:
%              hellip = hyperellipsoid(mu, inv(sig), calpha);
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
% EITHER EXPRESS, IMPLIED, STATUTORY OR OTHERWISE INCLUDING BUT NOT LIMITED TO
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, FREE OF
% DEFECTS AND NONINFRINGEMENT. 
% 
% UNDER NO CIRCUMSTANCES AND UNDER NO LEGAL THEORY OF LIABILITY, WHETHER TORT
% (INCLUDING NEGLIGENCE), CONTRACT OR OTHERWISE SHALL THE AUTHORS OR THEIR 
% EMPLOYERS BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR 
% CONSEQUENTIAL DAMAGES OF ANY KIND, INCLUDING, WITHOUT LIMITATION, DAMAGES 
% FOR LOST PROFITS, LOSS OF GOODWILL, WORK STOPPPAGE, COMPUTER FAILURE OR 
% MALFUNCTION, LOSS OF USE, LOSS OF DATA, OR ANY AND ALL OTHER COMMERCIAL 
% DAMAGES AND LOSSES WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES, 
% ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE. 
% THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH 
% YOU. IF THE SOFTWARE PROVES DEFECTIVE IN ANY RESPECT, YOU ASSUME THE COST OF 
% ANY NECESSARY SERVICING, REPAIR OR CORRECTION  
% THIS SOFTWARE IS RELEASED INTO THE PUBLIC DOMAIN, OCT 2012.

% Author: Mark D. Flood
% Research and Analysis Center, Office of Financial Research
% Oct 2012; Last revision: 22-Nov-2010

%------------- BEGIN CODE --------------
    size = chi2inv(prob, d);
end
